DSSessionManager class

Session management for Auth0 authentication provider Handles user sessions, device tracking, and session lifecycle

Constructors

DSSessionManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAllSessions() → void
Clears all sessions
createSession({required String userId, required String deviceId}) → Future<void>
Creates a new session for a user
getActiveSessions(String userId) → List<DSAuthSession>
Gets all active sessions for a user
getDeviceCount(String userId) → int
Gets device count for a user
getSessionForUser(String userId) → DSAuthSession?
Gets session for a user
isSessionActive(String sessionId) → bool
Validates if a session is active
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeSession(String userId) → Future<void>
Removes a session for a user
toString() → String
A string representation of this object.
inherited
updateSessionActivity(String sessionId) → void
Updates session activity

Operators

operator ==(Object other) → bool
The equality operator.
inherited