DSTokenManager class

Token management for Auth0 authentication provider Handles JWT token storage, validation, and lifecycle management

Constructors

DSTokenManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAllTokens() → void
Clears all tokens
getAllTokens() → Map<String, String>
Gets all active tokens
getToken(String userId) → String?
Retrieves a token for a user
isTokenExpired(String userId) → bool
Checks if a token is expired
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeToken(String userId) → Future<void>
Removes a token for a user
storeToken(String userId, String token) → Future<void>
Stores a token for a user
toString() → String
A string representation of this object.
inherited
validateTokenFormat(String token) → bool
Validates a JWT token format

Operators

operator ==(Object other) → bool
The equality operator.
inherited