DSAuthSession class

Represents an authentication session

Constructors

DSAuthSession({required String sessionId, required String userId, required String deviceId, required DateTime createdAt, required DateTime lastActivity})

Properties

createdAt DateTime
final
deviceId String
final
hashCode int
The hash code for this object.
no setterinherited
lastActivity DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
userId String
final

Methods

copyWith({String? sessionId, String? userId, String? deviceId, DateTime? createdAt, DateTime? lastActivity}) DSAuthSession
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited